@@ -1,31 +1,34 @@
 from .curve import (
-    bisect_left_keyframe,
-    bisect_left_value,
-    bisect_right_keyframe,
-    bisect_right_value,
     Composition,
     Curve,
-    eased_lerp,
-    EaseIn, 
-    EaseOut,
+    CurveBase,
     Keyframe,
     ParameterGroup,
-    register_interpolation_method,
-    SmoothCurve,
 )
+from .interpolation import (
+    bisect_left_keyframe, 
+    bisect_right_keyframe, 
+    register_interpolation_method,
+)
+from .misc import (
+    SmoothCurve,
+    SinusoidalCurve,
+    HawkesProcessIntensity,
+)
+from .serialization import to_yaml
+
 
 __all__ = [
     'bisect_left_keyframe',
-    'bisect_left_value',
     'bisect_right_keyframe',
-    'bisect_right_value',
     'Composition',
     'Curve',
-    'eased_lerp',
-    'EaseIn', 
-    'EaseOut',
+    'CurveBase',
+    'HawkesProcessIntensity',
     'Keyframe',
     'ParameterGroup',
     'register_interpolation_method',
     'SmoothCurve',
+    'SinusoidalCurve',
+    'to_yaml',
     ]
\ No newline at end of file
